@@ -39,7 +39,7 @@ class BaseNode(object):
         self.units = None
         self.numberFormat = None
         self.color = None
-        self.errorInDef = False
+        self._errorInDef = False
         self.nodeClass = nodeClass if not nodeClass is None else "variable"
         self._definition = self.getDefaultDefinitionByClass(self.nodeClass)
         self.nodeInfo = self.getDefaultNodeinfoByClass(self.nodeClass)
@@ -53,7 +53,6 @@ class BaseNode(object):
         self.h = 50
 
         self._ioEngine = IOEngine(self)
-        self._resultMemory = 0
         self.system = False
         self.lastEvaluationTime = 0
         self.lastEvaluationConsole = ""
@@ -194,7 +193,6 @@ class BaseNode(object):
                 self._isCalc = False
                 self.profileParent = None
                 self._result = None
-                self._resultMemory = 0
 
     @property
     def isCalc(self):
@@ -225,7 +223,8 @@ class BaseNode(object):
 
     @property
     def usedMemory(self):
-        return (getsizeof(self.definition) + self._resultMemory) / 1024 / 1024
+        # keep to support backward compatibility
+        return 0
 
     @property
     def hasPicture(self):
@@ -284,11 +283,28 @@ class BaseNode(object):
         if value != self._identifier:
             if self._model.existNode(value):
                 raise ValueError("'The id '" + value + "' already exists")
+
+            if self.isCalc:
+                self.invalidate()
+
             if self._model.updateNodeIdInDic(self._identifier, value):
-                self.ioEngine.updateNodeId(self._identifier, value)
-                self._identifier = value
-                if self.isCalc:
-                    self.invalidate()
+                old_id = self._identifier
+                new_id = value
+                self._identifier = new_id
+                self.ioEngine.updateNodeId(old_id, new_id)
+
+    @property
+    def errorInDef(self):
+        if self.originalId and self.model.existNode(self.originalId):
+            return self.model.getNode(self.originalId)._errorInDef
+        return self._errorInDef
+
+    @errorInDef.setter
+    def errorInDef(self, value):
+        if self.originalId and self.model.existNode(self.originalId):
+            self.model.getNode(self.originalId)._errorInDef = value
+        else:
+            self._errorInDef = value
 
     @property
     def isIndexed(self):
@@ -410,14 +426,12 @@ class BaseNode(object):
         self._isCalc = False
         self.profileParent = None
         self._result = None
-        self._resultMemory = 0
 
     def invalidate(self, fromCircularNode=False):
         """Invalidate node result"""
         self._isCalc = False
         self.profileParent = None
         self._result = None
-        self._resultMemory = 0
         if self.isCircular() and not fromCircularNode:
             circularNodes = self.getSortedCyclicDependencies()
             for node in circularNodes:
@@ -446,16 +460,14 @@ class BaseNode(object):
             try:
                 tmpCode = self.compileDef(self._definition)
             except SyntaxError:
-                aa = 1
-                # TODO: get detail of error
+                pass
 
             if not tmpCode is None:
-                # TODO: if cp.excel.. in def and other node Id is excel then don't generate input for that node
                 nameList = self.parseNames(tmpCode)
                 finalList = []
                 for item in nameList:
                     if item and self.model.existNode(item):
-                        rxText = "[^!.a-zA-Z_]\\b(###)\\b(?!={1}(?!={1}))".replace(
+                        rxText = "(?<!\\.)\\b(###)\\b(?!={1}(?!={1}))".replace(
                             "###", item)
                         rx = re.compile(rxText)
                         if len(re.findall(rx, self.definition)) > 0:
@@ -564,7 +576,7 @@ class BaseNode(object):
                 if not extraParams is None:
                     for keyParam in extraParams:
                         localRes[keyParam] = extraParams[keyParam]
-                
+
                 customImports = self.model.getCustomImports()
                 if customImports:
                     for keyParam in customImports:
@@ -588,12 +600,8 @@ class BaseNode(object):
                     if self.nodeClass not in ["button", "module", "text"]:
                         if 'this' in localRes:
                             self._result = localRes['this']
-                            self._resultMemory = Helpers.getResultSize(
-                                self._result)
                         elif 'result' in localRes:
                             self._result = localRes['result']
-                            self._resultMemory = Helpers.getResultSize(
-                                self._result)
                         else:
                             self._result = None
                             if self.lastEvaluationConsole != "":
@@ -621,30 +629,32 @@ class BaseNode(object):
     def postCalculate(self):
         evaluator = Evaluator.createInstance(self._result)
         evaluator.postCalculate(self, self._result)
-        if self.nodeClass=="inputtable":
+        if self.nodeClass == "inputtable":
             self.validateInputTable(evaluator)
 
-    def validateInputTable(self,evaluator):
+    def validateInputTable(self, evaluator):
         """Validate inputs of the inputtable node"""
         da = self._result
-        if isinstance(da,xr.DataArray):
-            has_changed=False
+        if isinstance(da, xr.DataArray):
+            has_changed = False
             for dim in da.dims:
                 node_index = self.model.getNode(dim)
-                if list(node_index.result.values) != list(da.coords[dim].values): #values of index has changed
+                # values of index has changed
+                if list(node_index.result.values) != list(da.coords[dim].values):
                     has_changed = True
-                    _input_properties=None
+                    _input_properties = None
                     if "_input_properties" in self.definition:
-                        _input_properties =  self.model.evaluate(self._definition.split("# values")[0] + "result = _input_properties")
-                    else: 
-                        _input_properties = {"defaultValue":0.}
+                        _input_properties = self.model.evaluate(self._definition.split("# values")[
+                                                                0] + "result = _input_properties")
+                    else:
+                        _input_properties = {"defaultValue": 0.}
                     da = da.reindex({dim: list(node_index.result.values)})
                     da = da.fillna(_input_properties["defaultValue"])
 
             if has_changed:
                 self._result = da
-                self._definition = evaluator.generateNodeDefinition(self.model.nodeDic, self.identifier)
-
+                self._definition = evaluator.generateNodeDefinition(
+                    self.model.nodeDic, self.identifier)
 
     def parseNames(self, compiledCode):
         """Parse names used in node definition"""
@@ -662,8 +672,7 @@ class BaseNode(object):
         rx = re.compile(r"((?<!\w)(?<!\d)(?<!\.)" + re.escape(oldId) +
                         "(?!\d)(?!\w))(?=(?:[^\"]|[\"][^\"]*[\"])*$)")
         newDef = re.sub(rx, newId, self.definition)
-        self.definition = newDef
-        pass
+        self._definition = newDef
 
     def isCircular(self):
         """ Checks if the node is part of a cycle
@@ -822,8 +831,7 @@ class BaseNode(object):
                 }
 
             self._model.ws.sendDebugInfo(
-                self.identifier, self.title if self.title else "", "endCalc", self.lastEvaluationTime, resources["usedMemory"], resources["totalMemory"], fromDynamic=fromDynamic)
-
+                self.identifier, self.title if self.title else "", "endCalc", self.lastEvaluationTime, resources["usedMemory"], resources["totalMemory"], resources["maxMemory"], fromDynamic=fromDynamic)
 
     # ***********************************
     # *** CYCLICK EVALUATOR  METHODS  ***
