@@ -56,7 +56,6 @@ class Model(object):
         self._customImports = None
         self.company_code = None
         self.session_key = None
-        self.ws = None
         self.debugMode = None
         self.WS = WSClass
 
@@ -90,12 +89,6 @@ class Model(object):
         else:
             return None
 
-    def getTotalMemory(self):
-        res = 0
-        for node in self.nodeDic:
-            res = res+self.nodeDic[node].usedMemory
-        return res
-
     def getCurrentModelPath(self):
         if self.existNode('current_path'):
             return self.getNode('current_path').result
@@ -241,7 +234,7 @@ class Model(object):
         else:
             return False
 
-    def evaluateNode(self, nodeId, dims=None, rows=None, columns=None, summaryBy='sum', bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, resultType=""):
+    def evaluateNode(self, nodeId, dims=None, rows=None, columns=None, summaryBy='sum', bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         """Evaluate node. Call evaluator class for implement diferent evaluators."""
         if self.existNode(nodeId):
             result = None
@@ -253,10 +246,7 @@ class Model(object):
             if not result is None:
                 self.evaluationVersion += 1
                 evaluator = Evaluator.createInstance(result)
-                if not evaluator.checkStructure(result, resultType):
-                    raise ValueError("bad_node_structure")
-                    #raise exceptions.NotAcceptable("bad_node_structure")
-                return evaluator.evaluateNode(result, self.nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow)
+                return evaluator.evaluateNode(result, self.nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow, hideEmpty)
         return ''
 
     def executeButton(self, nodeId):
@@ -333,7 +323,7 @@ class Model(object):
                 evaluator = Evaluator.createInstance(result)
                 return evaluator.getCubeDimensionValues(result, self.nodeDic, nodeId, query)
 
-    def getCubeMetadata(self, nodeId, resultType=''):
+    def getCubeMetadata(self, nodeId):
         """Return metadata of cube. Used from pivotgrid"""
         if self.existNode(nodeId):
             result = None
@@ -344,9 +334,6 @@ class Model(object):
 
             if not result is None:
                 evaluator = Evaluator.createInstance(result)
-                if resultType:
-                    if not evaluator.checkStructure(result, resultType):
-                        raise ValueError("bad_node_structure")
                 return evaluator.getCubeMetadata(result, self.nodeDic, nodeId)
 
     def setNodeValueChanges(self, changes):
@@ -485,14 +472,12 @@ class Model(object):
     def updateNodeIdInDic(self, oldNodeId, newNodeId):
         """Update node identifier on all dictionary."""
         if self.existNode(oldNodeId):
-            newNodeId = self.clearId(newNodeId)
             self.nodeDic[newNodeId] = self.nodeDic[oldNodeId]
             for node in self.findNodes('moduleId', oldNodeId):
                 node.moduleId = newNodeId
             for node in self.findNodes('originalId', oldNodeId):
                 node.originalId = newNodeId
                 node._definition = 'result = ' + str(newNodeId)
-
             del self.nodeDic[oldNodeId]
             return True
         else:
@@ -930,7 +915,7 @@ class Model(object):
         moduleId = self.clearId(moduleId)
         if self.existNode(moduleId):
             for nodeId in nodeList:
-                if self.existNode(nodeId):
+                if self.existNode(nodeId) and nodeId != moduleId:
                     self.getNode(nodeId).moduleId = moduleId
                     res.append(nodeId)
         return res
@@ -1175,7 +1160,7 @@ class Model(object):
             opened = jsonpickle.decode(textModel)
         else:
             if not self.isLinux():
-                fileName = fileName.replace('/','\\')
+                fileName = fileName.replace('/', '\\')
             with open(fileName, 'r') as f:
                 opened = jsonpickle.decode(f.read())
                 f.close()
@@ -1585,12 +1570,16 @@ class Model(object):
         mem_used = (_read_int(
             '/sys/fs/cgroup/memory/memory.usage_in_bytes') - _read_cache()) / 1024/1024/1024
 
+        max_mem = _read_int(
+            '/sys/fs/cgroup/memory/memory.max_usage_in_bytes') / 1024/1024/1024
+
         # get cpu usage
 
         if onlyMemory:
             return {
                 'totalMemory': mem_limit,
-                'usedMemory': mem_used
+                'usedMemory': mem_used,
+                "maxMemory": max_mem
             }
         else:
 
@@ -1614,7 +1603,8 @@ class Model(object):
                 'usedMemory': mem_used,
                 'usedCPU': used_cpu,
                 'pid': self.getPID(),
-                'currentNode': current_node
+                'currentNode': current_node,
+                "maxMemory": max_mem
             }
 
     def ensureModelLibraries(self):
@@ -1659,7 +1649,7 @@ class Model(object):
         p = subprocess.Popen(split(cmd), stdout=subprocess.PIPE,
                              stderr=subprocess.PIPE, universal_newlines=True)
         nn = 0
-        while p.stdout is not None and nn < 240:
+        while p.stdout is not None and nn < 1200:
             # TODO: show feedback to ide using channels
             line = p.stdout.readline()
             if not line:
@@ -1766,12 +1756,23 @@ class Model(object):
                             top_level_file = os.path.join(
                                 _dir, folder, 'top_level.txt')
                             if os.path.isfile(top_level_file):
-                                top_level = str(
-                                    open(top_level_file).read()).replace('\n', '')
+                                top_level = ""
+                                try:
+                                    top_level = str(
+                                        open(top_level_file).read()).replace('\n', '')
+                                except Exception as ex:
+                                    top_level = str(
+                                        open(top_level_file, encoding="utf8").read()).replace('\n', '')
                                 metadata_file = os.path.join(
                                     _dir, folder, 'METADATA' if '.dist-info' in folder else 'PKG-INFO')
                                 if os.path.isfile(metadata_file):
-                                    metadata = str(open(metadata_file).read())
+                                    metadata = ""
+                                    try:
+                                        metadata = str(
+                                            open(metadata_file).read())
+                                    except Exception as ex:
+                                        metadata = str(
+                                            open(metadata_file, encoding="utf8").read())
                                     metadata_arr = metadata.split('\n')
                                     for metadata_item in metadata_arr:
                                         if str(metadata_item).startswith('Name: '):
