@@ -432,7 +432,9 @@ class PyplanFunctions(object):
             file_to_read = os.path.join(target_dir, f"{namedRange if namedRange else ''}.pkl") if os.path.isfile(
                 os.path.join(target_dir, f"{namedRange if namedRange else ''}.pkl")) else file_to_read_legacy
 
-            if os.path.isfile(file_to_read):
+            # Read from pickle if pickle is newer than Excel file. Otherwise, read directly from Excel file
+            # Avoids reading outdated pickle files
+            if (os.path.isfile(file_to_read)) and (os.path.getmtime(file_to_read) >= os.path.getmtime(filename)):
                 df = pd.read_pickle(file_to_read, compression='gzip')
                 if not indexes is None:
                     df.set_index(indexes, inplace=True)
@@ -708,7 +710,7 @@ class PyplanFunctions(object):
     def goal_seek(self, nodeIdX, nodeIdObjective, goal=0, startValue=1, matrixIndex=None):
         """ Finds the value of nodeIdX that makes nodeIdObjective equal to goal.
             nodeIdX: String with id of node X
-            nodeIdObjective: String with id of node X
+            nodeIdObjective: String with id of node Objective
             matrixIndex: Index for multidimensional goal seek
         """
         _getNodeFn = self.model.getNode
@@ -723,13 +725,27 @@ class PyplanFunctions(object):
                 _res = newton(_f, x0=startValue)
                 return _res
             else:
-                raise ValueError(
-                    "Multidimensional goal seek has not Implemented")
+                _indexName = matrixIndex.name
+                for item in matrixIndex:
+                    def _f(x):
+                        _values = _getNodeFn(nodeIdX).result
+                        _values.loc[{_indexName: slice(item, item)}] = x
+                        np.set_printoptions(
+                            threshold=np.prod(_values.values.shape))
+                        data = np.array2string(_values.values, separator=",", precision=20,
+                                               formatter={
+                                                   'float_kind': lambda x: "np.nan" if np.isnan(x) else repr(x)}
+                                               ).replace('\n', '')
+                        _getNodeFn(
+                            nodeIdX).definition = f"result = xr.DataArray({data},[{_indexName}])"
+                        value = _getNodeFn(nodeIdObjective).result
+                        return self.subscript(value, matrixIndex, item)
+                    _res = newton(_f, x0=startValue)
         else:
             raise ValueError("scipy library not found")
 
     def _exists_module(self, import_name):
-        """Return true if module is intalled
+        """Return true if module is installed
         """
         try:
             importlib.import_module(import_name)
@@ -1045,14 +1061,16 @@ class PyplanFunctions(object):
                 not_level_reverse] if not_level_reverse in ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE else ws_settings.NOTIFICATION_LEVEL_INFO
             self.model.ws.sendMsg(message_text, message_title, not_level)
 
-    def progressbar(self, progress, message_text=""):
+    def progressbar(self, progress, message_text="", not_level_reverse="info"):
         """Create and update progress bar. Only used with Pyplan UI
             Ex.
-                pp.progressbar(20, "Step 1")
-                pp.progressbar(100, "Complete!")
+                pp.progressbar(20, "Step 1","info")
+                pp.progressbar(100, "Complete!","success")
         """
         if self.model and self.model.ws:
-            self.model.ws.progressbar(progress, message_text)
+            not_level = ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE[
+                not_level_reverse] if not_level_reverse in ws_settings.NOTIFICATION_LEVEL_CHOICES_REVERSE else ws_settings.NOTIFICATION_LEVEL_INFO
+            self.model.ws.progressbar(progress, message_text, not_level)
 
     def create_report(self, reportItems, reportIndexName="Report index", reportIndex=None):
         """ Concatenate the reportItems dic dataarrays along the reportIndex dimension
@@ -1310,14 +1328,14 @@ class Pandas_from_acc():
 
     # private class methods
     @classmethod
-    def __get_tables(rdb_file, encoding='utf8'):
+    def __get_tables(cls, rdb_file, encoding='utf8'):
         output = subprocess.check_output(['mdb-schema', rdb_file])
         lines = output.decode(encoding).splitlines()
         schema_ddl = "\n".join(l for l in lines if l and not l.startswith('-'))
         return Pandas_from_acc.TABLE_RE.findall(schema_ddl)
 
     @classmethod
-    def __extract_dtype(data_type):
+    def __extract_dtype(cls, data_type):
         # Note, this list is surely incomplete. But, I only had one .mdb file
         # at the time of creation. If you see a new data-type, patch-pull or just
         # open an issue.
@@ -1336,7 +1354,7 @@ class Pandas_from_acc():
             return None
 
     @classmethod
-    def __extract_defs(defs_str):
+    def __extract_defs(cls, defs_str):
         defs = {}
         lines = defs_str.splitlines()
         for line in lines:
