@@ -6,17 +6,16 @@ import pandas as pd
 from pyplan_core.classes.evaluators.BaseEvaluator import BaseEvaluator
 from pyplan_core.classes.common.filterChoices import filterChoices
 from pyplan_core.classes.common.indexValuesReq import IndexValuesReq
+from pyplan_core.classes.ws.settings import ws_settings
 from pyplan_core.cubepy.cube import kindToString
 from pyplan_core import cubepy
 
 
 class PandasEvaluator(BaseEvaluator):
 
-    PAGESIZE = 100
     MAX_COLUMS = 5000
 
-    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
-        result_structure = self.getStructure(result)
+    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         sby = np.nansum
         if summaryBy == 'avg':
             sby = np.nanmean
@@ -31,6 +30,7 @@ class PandasEvaluator(BaseEvaluator):
             toRow = 100
         fromRow = int(fromRow)
         toRow = int(toRow)
+        pagesize = toRow - fromRow + 1
 
         _filters = {}
         _rows = []
@@ -80,12 +80,37 @@ class PandasEvaluator(BaseEvaluator):
             dfResult = pd.DataFrame.pivot_table(
                 _filteredDataFrame, index=_rows, columns=_columns, aggfunc=sby, margins=False, margins_name="Total")
 
+            # apply orders to result (pivot_table don't mantain the original order)
+            if len(_rows) > 0:
+                dfResult = dfResult.reindex(
+                    index=_filteredDataFrame.index.get_level_values(_rows[0]).unique().tolist())
+            if len(_columns) > 0:
+                level = 1 if isinstance(dfResult.columns, pd.MultiIndex) and len(
+                    dfResult.columns.levels) > 1 else 0
+                dfResult = dfResult.reindex(columns=_filteredDataFrame.index.get_level_values(
+                    _columns[0]).unique().tolist(), level=level)
+
             if needT:
                 dfResult = dfResult.T
                 aux = _rows
                 _rows = _columns
                 _columns = aux
 
+            if hideEmpty:
+                try:
+                    if hideEmpty in ["row", "both"]:
+                        filter_expresion = (dfResult != 0).any(axis=1)
+                        dfResult = dfResult.loc[filter_expresion]
+                    if hideEmpty in ["column", "both"]:
+                        filter_expresion = (dfResult != 0).any(axis=0)
+                        dfResult = dfResult.loc[:, filter_expresion]
+                except Exception as ex:
+                    try:
+                        nodeDic[nodeId].model.ws.sendMsg(str(ex), 'Error applying empty data filter',
+                                                         not_level=ws_settings.NOTIFICATION_LEVEL_ERROR)
+                    except:
+                        pass
+
             if bottomTotal and dfResult.shape[0] > 1:
                 row_total = sby(dfResult.values, axis=0)
                 new_values = np.concatenate(
@@ -105,7 +130,7 @@ class PandasEvaluator(BaseEvaluator):
                     data=new_values, columns=new_columns, index=dfResult.index)
                 dfResult = _df
 
-        if (dfResult.shape[0] > self.PAGESIZE):
+        if (dfResult.shape[0] > pagesize):
             if int(toRow) > dfResult.shape[0]:
                 toRow = dfResult.shape[0]
             pageInfo = {
@@ -123,32 +148,7 @@ class PandasEvaluator(BaseEvaluator):
             res = dfResult[:PandasEvaluator.MAX_COLUMS].to_json(
                 orient='split', date_format='iso')
 
-        return self.createResult(res, result_structure, resultIsJson=True, pageInfo=pageInfo, node=nodeDic[nodeId],  onRow=(_rows[0] if len(_rows) > 0 else None), onColumn=(_columns[0] if len(_columns) > 0 else None))
-
-    def getStructure(self, result):
-        structure = dict()
-        structure["type"] = str(type(result))
-        structure["columns"] = list(result.columns) if isinstance(
-            result, pd.DataFrame) else []
-        structure["indexes"] = []
-        if self.isIndexed(result):
-            structure["indexes"] = list(result.index.names)
-        return structure
-
-    def checkStructure(self, result, resultType):
-        """ Check current vs result structure. Result False for distinct structure """
-        res = True
-        if resultType:
-            try:
-                structure = json.loads(resultType)
-                result_structure = self.getStructure(result)
-                res = structure["type"] == result_structure["type"] and all(elem in list(result_structure["columns"])
-                                                                            for elem in list(structure["columns"])) and all(elem in list(result_structure["indexes"])
-                                                                                                                            for elem in list(structure["indexes"]))
-            except Exception as ex:
-                print(f"Error checking structure: {ex}")
-
-        return res
+        return self.createResult(res, resultIsJson=True, pageInfo=pageInfo, node=nodeDic[nodeId],  onRow=(_rows[0] if len(_rows) > 0 else None), onColumn=(_columns[0] if len(_columns) > 0 else None))
 
     def addToFilter(self, dim, filters):
         if "values" in dim and dim["values"] is not None and len(dim["values"]) > 0:
@@ -303,8 +303,8 @@ class PandasEvaluator(BaseEvaluator):
                 "isEditable": False,
                 "nodeProperties": {
                     "title": nodeDic[nodeId].title if not nodeDic[nodeId].title is None else nodeDic[nodeId].identifier,
+                    "description": nodeDic[nodeId].description,
                     "numberFormat": nodeDic[nodeId].numberFormat,
-                    "resultType": json.dumps(self.getStructure(result))
                 }
             }
 
@@ -398,6 +398,11 @@ class PandasEvaluator(BaseEvaluator):
             _groupedDF = _filteredResult.agg(_agg).to_frame("Total").T if len(
                 _cols) == 0 else _filteredResult.groupby(_cols, sort=False).agg(_agg)
 
+            # apply reindex only if have 1 dimension. groupby work fine with sort=False with two or more dims.
+            if len(_cols) == 1:
+                _groupedDF = _groupedDF.reindex(
+                    index=_result.index.get_level_values(_cols[0]).unique().to_list())
+
             if useCustomFillMeasures:
                 self._applyGroupMeasures(_groupedDF, _result.groupMeasures)
 
@@ -502,6 +507,9 @@ class PandasEvaluator(BaseEvaluator):
         """
         if node.nodeClass == "index":
             if isinstance(result, pd.Index):
+                if result.isna().any():
+                    raise ValueError(
+                        "Nan/None values are not allowed in indexes")
                 result.name = node.identifier
 
     def copyAsValues(self, result, nodeDic, nodeId):
