@@ -9,19 +9,18 @@ from pyplan_core.classes.evaluators.BaseEvaluator import BaseEvaluator
 from pyplan_core.classes.evaluators.PandasEvaluator import PandasEvaluator
 from pyplan_core.classes.common.filterChoices import filterChoices
 from pyplan_core.classes.common.indexValuesReq import IndexValuesReq
+from pyplan_core.classes.ws.settings import ws_settings
 
 
 class XArrayEvaluator(BaseEvaluator):
 
-    PAGESIZE = 100
     MAX_COLUMS = 5000
 
-    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
+    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         if isinstance(result, xr.DataArray):
-            return self.cubeEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow)
+            return self.cubeEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow, hideEmpty)
 
-    def cubeEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
-        result_structure = self.getStructure(result)
+    def cubeEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         sby = np.nansum
         if summaryBy == 'avg':
             sby = np.nanmean
@@ -36,6 +35,8 @@ class XArrayEvaluator(BaseEvaluator):
             toRow = 100
         fromRow = int(fromRow)
         toRow = int(toRow)
+        pagesize = toRow - fromRow + 1
+
 
         result = self.applyHierarchy(
             result, nodeDic, nodeId, dims, rows, columns, sby)
@@ -100,6 +101,24 @@ class XArrayEvaluator(BaseEvaluator):
             else:
                 tmp = filteredResult.transpose(*(_rows + _columns))
 
+        # Apply Hide Empty
+        if hideEmpty:
+            try:
+                _filter = tmp.fillna(0) == 0
+                if hideEmpty in ["row", "column"] and len(_rows) > 0 and len(_columns) > 0:
+                    if hideEmpty == "row":
+                        tmp = tmp.where(~_filter.all(_columns[0]), drop=True)
+                    else:
+                        tmp = tmp.where(~_filter.all(_rows[0]), drop=True)
+                else:
+                    tmp = tmp.where(~_filter, drop=True)
+            except Exception as ex:
+                try:
+                    nodeDic[nodeId].model.ws.sendMsg(str(ex), 'Error applying empty data filter',
+                                                     not_level=ws_settings.NOTIFICATION_LEVEL_ERROR)
+                except:
+                    pass
+
         finalValues = tmp.values
         finalIndexes = []
         if tmp.ndim > 0:
@@ -164,7 +183,7 @@ class XArrayEvaluator(BaseEvaluator):
             }
         elif len(_columns) == 0:
 
-            if (len(finalIndexes) > self.PAGESIZE):
+            if (len(finalIndexes) > pagesize):
                 pageInfo = {
                     "fromRow": int(fromRow),
                     "toRow": int(toRow),
@@ -186,7 +205,7 @@ class XArrayEvaluator(BaseEvaluator):
             onColumn = _columns[0]
             onRow = _rows[0]
 
-            if (len(finalIndexes) > self.PAGESIZE):
+            if (len(finalIndexes) > pagesize):
                 pageInfo = {
                     "fromRow": int(fromRow),
                     "toRow": int(toRow),
@@ -205,27 +224,7 @@ class XArrayEvaluator(BaseEvaluator):
                 res["data"].append(
                     _totalRow[:XArrayEvaluator.MAX_COLUMS].tolist())
 
-        return self.createResult(res, result_structure, onRow=onRow, onColumn=onColumn, node=nodeDic[nodeId], pageInfo=pageInfo)
-
-    def getStructure(self, result):
-        structure = dict()
-        structure["type"] = str(type(result))
-        structure["dims"] = list(result.dims)
-        return structure
-
-    def checkStructure(self, result, resultType):
-        """ Check current vs result structure. Result False for distinct structure """
-        res = True
-        if resultType:
-            try:
-                structure = json.loads(resultType)
-                result_structure = self.getStructure(result)
-                res = structure["type"] == result_structure["type"] and all(elem in list(result_structure["dims"])
-                                                                            for elem in list(structure["dims"]))
-            except Exception as ex:
-                print(f"Error checking structure: {ex}")
-
-        return res
+        return self.createResult(res, onRow=onRow, onColumn=onColumn, node=nodeDic[nodeId], pageInfo=pageInfo)
 
     def hasDim(self, result, dim):
         return True if dim.split(".")[0] in result.dims else False
@@ -470,8 +469,8 @@ class XArrayEvaluator(BaseEvaluator):
                 "isEditable": True if self.isTable(nodeDic[nodeId]) == "1" else False,
                 "nodeProperties": {
                     "title": nodeDic[nodeId].title if not nodeDic[nodeId].title is None else nodeDic[nodeId].identifier,
+                    "description": nodeDic[nodeId].description,
                     "numberFormat": nodeDic[nodeId].numberFormat,
-                    "resultType": json.dumps(self.getStructure(result))
                 }
             }
 
